@@ -1,5 +1,6 @@
 from django.core.management.base import BaseCommand
 from django.utils import timezone
+from django.utils.timezone import get_current_timezone as ltz
 
 from post_deploy.local_utils import initialize_actions, get_context_manager, get_scheduler_manager, model_ok
 
@@ -26,7 +27,7 @@ class Command(BaseCommand):
                             help="Execute all pending actions no matter the value of auto.")
         parser.add_argument('--one', help="Execute one of the actions.")
         parser.add_argument('--once', help="Execute the given action if it is not completed correctly.")
-        parser.add_argument('--skip', const=True, action='store_const', help="Execute the given action if it is not completed correctly.")
+        parser.add_argument('--skip', const=True, action='store_const', help="Skip all unprocessed tasks.")
 
     def handle(self, *args, **options):
         self.context_manager = get_context_manager(None)
@@ -91,17 +92,18 @@ class Command(BaseCommand):
         if PostDeployLog.objects.running().exists():
             self.stdout.write("\nCurrently running actions:")
             for action in PostDeployLog.objects.running():
-                self.stdout.write(f"* {action.import_name} ({action.started_at or action.created_at})")
+                start = action.started_at or action.created_at
+                self.stdout.write(f"* {action.import_name} ({start.astimezone(ltz())})")
 
         if PostDeployLog.objects.completed().with_errors().exists():
             self.stdout.write("\nActions that failed:")
             for action in PostDeployLog.objects.with_errors():
-                self.stdout.write(f"* {action.import_name} ({action.completed_at} {action.message})")
+                self.stdout.write(f"* {action.import_name} ({action.completed_at.astimezone(ltz())} {action.message})")
 
         if PostDeployLog.objects.completed().order_by('-completed_at').exists():
             self.stdout.write("\nCompleted actions:")
             for action in PostDeployLog.objects.completed().order_by('-completed_at'):
-                self.stdout.write(f"* {action.import_name} ({action.completed_at})")
+                self.stdout.write(f"* {action.import_name} ({action.completed_at.astimezone(ltz())})")
 
     def do_todo(self):
         auto_actions = PostDeployLog.objects.auto(self._bindings)
